# Copyright (c) 2000-2014, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section free


Name:           hawtdispatch
Summary:        HawtDispatch threadpooling and NIO framework
Url:            http://hawtdispatch.fusesource.org/
Version:        1.12
Release:        1%{?dist}
Epoch:          0
License:        Apache Software License 2.0
Group:          Development/Libraries/Java
Source0:        hawtdispatch-1.12.tar.bz2
# git clone https://github.com/fusesource/hawtdispatch.git
# git archive --prefix=hawtdispatch-1.12/ --format=tar hawtdispatch-project-1.12 | bzip2 > ../../SOURCES/hawtdispatch-1.12.tar.bz2

Source1:        hawtdispatch-jpp-depmap.xml
Patch0:         hawtdispatch-pom.patch
Patch1:         hawtdispatch-SSLClientExample.patch

BuildArch:      noarch
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  scala29
BuildRequires:  maven3
BuildRequires:  maven-shared-dependency-analyzer
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  maven-scala-plugin
BuildRequires:  fusesource-mvnplugins
BuildRequires:  fusesource-pom
BuildRequires:  hawtbuf >= 0:1.9
BuildRequires:  scalatest-for-scala29

Requires:  java >= 0:1.6.0
Requires:  scala29
Requires:  hawtbuf >= 0:1.9

BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot

%description
HawtDispatch is a small ( less than 100k ) thread pooling 
and NIO handling framework API modeled after the libdispatch 
API. libdispatch is the API that Apple created to power the 
Grand Central Dispatch (GCD) technology in OS X. It allows 
you to more easily develop multi-threaded applications which 
can more easily scale to take advantage of all the 
processing cores on your machine. At the same time, it's 
development model simplifies solving many of the problems 
that plague multi-threaded NIO development.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
Javadoc for %{name}.

%prep
%setup -q 
%patch0 -b .sav0
%patch1 -b .sav1

%build
export MAVEN_REPO_LOCAL=$(pwd)/m2_repo

mvn-rpmbuild -e \
        -Dmaven.test.failure.ignore=true \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        -Dmaven.local.depmap.file=%{SOURCE1} \
        install javadoc:aggregate

%install
# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms

install -m 644 hawtdispatch/target/%{name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
install -m 644 hawtdispatch-transport/target/%{name}-transport-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-transport-%{version}.jar
install -m 644 hawtdispatch-example/target/%{name}-example-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-example-%{version}.jar
install -m 644 hawtdispatch-scala/target/%{name}-scala-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-scala-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)

install -m 644 pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-project.pom
%add_to_maven_depmap org.fusesource.hawtdispatch hawtdispatch-project %{version} JPP %{name}-project
install -m 644 hawtdispatch/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap org.fusesource.hawtdispatch hawtdispatch %{version} JPP %{name}
install -m 644 hawtdispatch-transport/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-transport.pom
%add_to_maven_depmap org.fusesource.hawtdispatch hawtdispatch-transport %{version} JPP %{name}-transport
install -m 644 hawtdispatch-example/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-example.pom
%add_to_maven_depmap org.fusesource.hawtdispatch hawtdispatch-example %{version} JPP %{name}-example
install -m 644 hawtdispatch-scala/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}-scala.pom
%add_to_maven_depmap org.fusesource.hawtdispatch hawtdispatch-scala %{version} JPP %{name}-scala

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root)
%doc *.txt
%{_javadir}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc
%defattr(-,root,root)
%{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%changelog
* Sat Jul 19 2014 Ralph Apel <r.apel at r-apel.de> 0:1.12-1jpp
- First release
